function p = AUSWSPLINE(x,f,M,z)
% p = AUSWSPLINE(x,f,M,z)
%
% Interpolation mittels kubischer Splines und natürlicher Randbedingung bei
% gegebenen Stützstellen x, Funktionswerten f und Momenten M gleicher Länge
% sowie der zu untersuchenden Stelle z. 
%
% Das Programm wertet den Spline im Intervall [x(j),x(j+1)] aus, in welchem z
% liegt. Das Ergebnis wird in p abgelegt
%
% -----------------------------------------------------------------------------
%
% Eingabe
% -------
% x         Stützstellenvektor
% f         Funktionswerte
% M         Vektor der Momente
% z         Stelle, an der derSpline ausgewertet werden soll
%
% -----------------------------------------------------------------------------
% 
% Ausgabe
% -------
% p         Wert des Splines an der Stelle z



